Citing CIDER and CiderPress
Choose citations according to the functional family and feature methodology used in the calculation. Also make sure to cite PySCF [1], since it is integral to the code, and make sure to cite GPAW [2] if you use the GPAW calculation interface. See the respective codes’ websites for how to cite them.
CIDER23X and molecular/periodic NLDF evaluation
Cite Bystrom and Kozinsky[3] for CIDER23X models and for the molecular or PAW/FFT implementations of NLDF evaluation.
CIDER24X and SDMX/eigenvalue training
For CIDER24X models, SDMX descriptors, or the orbital-energy training framework, additionally cite Bystrom et al.[4].
CIDER26XC
The CIDER26XC packaged models are described in the forthcoming manuscript Abdallah et al.[5].
Citing the software
Cite the CiderPress software by its repository, github.com/mir-group/CiderPress, and the version used (for example, CiderPress 0.5.0).
Also cite the host electronic-structure code and any separately evaluated method such as D4. Packaged model names and checksums are listed in Choosing a CIDER Functional.